/**
*	15-100, 15-111 Intro sections
*	Class FileInput
*	@author		Jim Roberts, Mark Stehlik, Don Slater
*	@Date		09/20/01
*/


import java.io.*;
import java.util.*;

public class FileInput {

	/**
	* instance variables
	* FileReader, BufferedReader, String, String, StringTokenizer
	*/
	private FileReader textFile;
	private BufferedReader file;
	String str;
	String fileName;
	StringTokenizer sTok;
	
	ConsoleInput io;

	/**
	* 
	* the prompt argument can be used to ask the user to specify a
	* filename
	* catches IOException
	* @param String prompt
	*/
	public FileInput(String prompt) {
	
		try {

			io = new ConsoleInput();

			fileName = io.promptAndRead(prompt);
			textFile = new FileReader(fileName);
			file = new BufferedReader(textFile);

			io.writeln("File " + fileName + " has been opened.");
		} catch(IOException e) {
			io.writeln("Error opening file " + fileName + ".");
			io.writeln("Program will terminate.");
			System.exit(1);
		}
	}

	/**
	* closes open file
	* uses instance variables file, fileName, and io
	* catches IOException
	*/
	public void close() {
	
		try {
			file.close();
			io.writeln("File " + fileName + " has been closed.");
		} catch (IOException e) {
			io.writeln("Error closing file " + fileName + ".");
			io.writeln("Program will terminate.");
			System.exit(1);
		}
	}

	/**
	* guards for end of file
	* uses instance variables file, sTok
	* catches IOException
	* @return boolean
	*/
	public boolean eof() {
	
		try {
			if ((str = file.readLine() ) == null) {
				sTok = null;
				return true;
			} else {
				sTok = new StringTokenizer(str);
				return false;
			}
		} catch (IOException e) {
			io.writeln("Error reading from file " + fileName + ".");
			io.writeln("Program will terminate.");
			System.exit(1);
		}
		return false;
	}
	

	/** 
	* return an int from a file
	* uses instance variables sTok
	* @return int
	*/
	
	public int getInt() {

		if (sTok.hasMoreTokens()) {
			return Integer.parseInt(sTok.nextToken());
		} else {
			io.writeln("Problems reading int value from file " + fileName + ".");
			io.writeln("Program will terminate.");
			System.exit(1);
		}
		return 0;
	}

	/** 
	* return a double from a file
	* uses instance variables sTok
	* @return double
	*/
	
	public double getDouble() {

		if (sTok.hasMoreTokens()) {
			return Double.parseDouble(sTok.nextToken());
		} else {
			io.writeln("Problems reading double value from file " + fileName + ".");
			io.writeln("Program will terminate.");
			System.exit(1);
		}
		return 0.0;
	}
	/** 
	* return a boolean from a file
	* uses instance variables sTok
	* @return boolean
	*/
	
	public boolean getBoolean() {

		if (sTok.hasMoreTokens()) {
			return Boolean.valueOf(sTok.nextToken()).booleanValue();
		} else {
			io.writeln("Problems reading boolean value from file " + fileName + ".");
			io.writeln("Program will terminate.");
			System.exit(1);
		}
		return false;
	}

	/** 
	* return a char from a file
	* uses instance variables sTok
	* @return char
	*/
	
	public char getChar() {

		if (sTok.hasMoreTokens()) {
			return sTok.nextToken().charAt(0);
		} else {
			io.writeln("Problems reading char value from file " + fileName + ".");
			io.writeln("Program will terminate.");
			System.exit(1);
		}
		return ' ';
	}
	/** 
	* return a String from a file  with no trailing or leading white space
	* uses instance variables sTok
	* @return String
	*/
	
	public String getStringNoWhiteSpace() {

		if (sTok.hasMoreTokens()) {
			return sTok.nextToken().trim();
		} else {
			io.writeln("Problems reading String value from file " + fileName + ".");
			io.writeln("Program will terminate.");
			System.exit(1);
		}
		return "";
	}

	/** 
	* return a String from a file 
	* uses instance variables sTok
	* @return String
	*/
	
	public String getString() {

		if (sTok.hasMoreTokens()) {
			String temp = "";
			while (sTok.hasMoreTokens()) {
				temp = temp + " " + sTok.nextToken();
			}
			return temp.trim();
		} else {
			io.writeln("Problems reading String value from file " + fileName + ".");
			io.writeln("Program will terminate.");
			System.exit(1);
		}
		return "";
	}

}

